==> reference3-1.0-sources.jar: one/xingyi/reference3/person/client/view/PersonNameViewDebugInfo.java <==
package one.xingyi.reference3.person.client.view;
//Made by one.xingyi.core.filemaker.ViewDomDebugFileMaker
//Defn one.xingyi.reference3.person.IPersonNameViewDefn
import java.lang.String;
public class PersonNameViewDebugInfo {
/*
Deprecated: false
Original: one.xingyi.reference3.person.IPersonNameViewDefn
    Entity:     one.xingyi.reference3.person.client.entitydefn.IPersonNameViewClientEntity
    View:        one.xingyi.reference3.person.client.view.PersonNameView
    Impl   :    one.xingyi.reference3.person.client.view.PersonNameViewImpl
    ServerImpl: one.xingyi.reference3.person.client.viewcompanion.PersonNameViewCompanion
    Original: one.xingyi.reference3.person.IPersonDefn
        IServer:    one.xingyi.reference3.person.server.domain.IPerson
        ServerImpl: one.xingyi.reference3.person.server.domain.Person
        Client:     one.xingyi.reference3.person.client.entitydefn.IPersonClientEntity
        ServComp:   one.xingyi.reference3.person.server.companion.PersonCompanion
        Lens:       Person
Fields: 1
    Field: name
        PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String))
        Lens path  lens path for views not done yet
        Lens name  lens for views not done yet
        Readonly   false
        Javascript functionlensforviewsnotdoneyet(){returnlens('name');};
        Templated: false
        Deprecated false

Deprecated: false
Original: one.xingyi.reference3.person.IPersonDefn
    IServer:    one.xingyi.reference3.person.server.domain.IPerson
    ServerImpl: one.xingyi.reference3.person.server.domain.Person
    Client:     one.xingyi.reference3.person.client.entitydefn.IPersonClientEntity
    ServComp:   one.xingyi.reference3.person.server.companion.PersonCompanion
    Lens:       Person
bookmarkAndUrl Optional[BookmarkCodeAndUrlPattern(bookmark=/person, urlPattern={host}/person/{id}, code={host}/person/code)]
Fields: 7
    Field: name
        PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String))
        Lens path  name/String
        Lens name  lens_Person_name
        Readonly   false
        Javascript functionlens_Person_name(){returnlens('name');};
        Templated: false
        Deprecated false
    Field: age
        PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=Integer))
        Lens path  age/Integer
        Lens name  lens_Person_age
        Readonly   false
        Javascript functionlens_Person_age(){returnlens('age');};
        Templated: false
        Deprecated false
    Field: addresses
        ListType(fullTypeName=one.xingyi.core.client.IResourceList<one.xingyi.reference3.address.IAddressLine12ViewDefn>, nested=ViewType(typeName=one.xingyi.reference3.address.IAddressLine12ViewDefn, forEntity=one.xingyi.reference3.address.server.domain.IAddress, forView=one.xingyi.reference3.address.client.view.AddressLine12View, viewCompanion=one.xingyi.reference3.address.client.viewcompanion.AddressLine12ViewCompanion, serverCompanion=one.xingyi.reference3.address.server.companion.AddressCompanion, entityNameForLens=Address), companionName=PackageAndClassName(packageName=one.xingyi.reference3.address.server.companion, className=AddressCompanion), entityNameForLens=Address)
        Lens path  addresses/*Address
        Lens name  lens_Person_addresses
        Readonly   false
        Javascript functionlens_Person_addresses(){returnlens('addresses');};
        Templated: false
        Deprecated false
    Field: telephone
        ViewType(typeName=one.xingyi.reference3.telephone.ITelephoneNumberViewDefn, forEntity=one.xingyi.reference3.telephone.server.domain.ITelephoneNumber, forView=one.xingyi.reference3.telephone.client.view.TelephoneNumberView, viewCompanion=one.xingyi.reference3.telephone.client.viewcompanion.TelephoneNumberViewCompanion, serverCompanion=one.xingyi.reference3.telephone.server.companion.TelephoneNumberCompanion, entityNameForLens=TelephoneNumber)
        Lens path  telephone/TelephoneNumber
        Lens name  lens_Person_telephone
        Readonly   false
        Javascript functionlens_Person_telephone(){returnlens('telephone');};
        Templated: false
        Deprecated false
    Field: address
        ViewType(typeName=one.xingyi.reference3.address.IAddressLine12ViewDefn, forEntity=one.xingyi.reference3.address.server.domain.IAddress, forView=one.xingyi.reference3.address.client.view.AddressLine12View, viewCompanion=one.xingyi.reference3.address.client.viewcompanion.AddressLine12ViewCompanion, serverCompanion=one.xingyi.reference3.address.server.companion.AddressCompanion, entityNameForLens=Address)
        Lens path  addresses/*address,{firstItem}
        Lens name  lens_Person_address
        Readonly   false
        Javascript functionlens_Person_address(){returncompose(lens_Person_addresses(),lensForFirstItemInList());};
        Templated: false
        Deprecated true
    Field: line1
        PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String))
        Lens path  addresses/*address,{firstItem},line1/string
        Lens name  lens_Person_line1
        Readonly   false
        Javascript functionlens_Person_line1(){returncompose(lens_Person_address(),lens('line1'));};
        Templated: false
        Deprecated true
    Field: line2
        PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String))
        Lens path  addresses/*address,{firstItem},line2/string
        Lens name  lens_Person_line2
        Readonly   false
        Javascript functionlens_Person_line2(){returncompose(lens_Person_address(),lens('line2'));};
        Templated: false
        Deprecated true
Get            Optional[GetDom()]
optionalGet    Optional[OptionalGetDom()]
Put            Optional[PutDom()]
Create         Optional[CreateDom()]
CreateNoId     Optional[CreateWithoutIdDom(path={host}/person)]
Delete         Optional[DeleteDom()]
prototype:     Optional[PrototypeDom(prototypeId=prototype)]
prototypeNoId: Optional.empty
Posts:         []
*/}

==> reference3-1.1-sources.jar: one/xingyi/reference3/person/client/view/PersonNameViewDebugInfo.java <==
package one.xingyi.reference3.person.client.view;
//Made by one.xingyi.core.filemaker.ViewDomDebugFileMaker
//Defn one.xingyi.reference3.person.IPersonNameViewDefn
import java.lang.String;
public class PersonNameViewDebugInfo {
/*
Deprecated: false
Original: one.xingyi.reference3.person.IPersonNameViewDefn
    Entity:     one.xingyi.reference3.person.client.entitydefn.IPersonNameViewClientEntity
    View:        one.xingyi.reference3.person.client.view.PersonNameView
    Impl   :    one.xingyi.reference3.person.client.view.PersonNameViewImpl
    ServerImpl: one.xingyi.reference3.person.client.viewcompanion.PersonNameViewCompanion
    Original: one.xingyi.reference3.person.IPersonDefn
        IServer:    one.xingyi.reference3.person.server.domain.IPerson
        ServerImpl: one.xingyi.reference3.person.server.domain.Person
        Client:     one.xingyi.reference3.person.client.entitydefn.IPersonClientEntity
        ServComp:   one.xingyi.reference3.person.server.companion.PersonCompanion
        Lens:       Person
Fields: 1
    Field: name
        StringPrimitiveType()
        Lens path  lens path for views not done yet
        Lens name  lens for views not done yet
        Readonly   false
        Javascript functionlensforviewsnotdoneyet(){returnlens('name');};
        Templated: false
        Deprecated false

Deprecated: false
Original: one.xingyi.reference3.person.IPersonDefn
    IServer:    one.xingyi.reference3.person.server.domain.IPerson
    ServerImpl: one.xingyi.reference3.person.server.domain.Person
    Client:     one.xingyi.reference3.person.client.entitydefn.IPersonClientEntity
    ServComp:   one.xingyi.reference3.person.server.companion.PersonCompanion
    Lens:       Person
bookmarkAndUrl Optional[BookmarkCodeAndUrlPattern(bookmark=/person, urlPattern={host}/person/{id}, code={host}/person/code)]
Fields: 7
    Field: name
        StringPrimitiveType()
        Lens path  name/String
        Lens name  lens_Person_name
        Readonly   false
        Javascript functionlens_Person_name(){returnlens('name');};
        Templated: false
        Deprecated false
    Field: age
        IntegerPrimitiveType()
        Lens path  age/Integer
        Lens name  lens_Person_age
        Readonly   false
        Javascript functionlens_Person_age(){returnlens('age');};
        Templated: false
        Deprecated false
    Field: addresses
        ListType(fullTypeName=one.xingyi.core.client.IResourceList<one.xingyi.reference3.address.IAddressLine12ViewDefn>, nested=ViewType(typeName=one.xingyi.reference3.address.IAddressLine12ViewDefn, forEntity=one.xingyi.reference3.address.server.domain.IAddress, forView=one.xingyi.reference3.address.client.view.AddressLine12View, viewCompanion=one.xingyi.reference3.address.client.viewcompanion.AddressLine12ViewCompanion, serverCompanion=one.xingyi.reference3.address.server.companion.AddressCompanion, entityNameForLens=Address), companionName=PackageAndClassName(packageName=one.xingyi.reference3.address.server.companion, className=AddressCompanion), entityNameForLens=Address)
        Lens path  addresses/*Address
        Lens name  lens_Person_addresses
        Readonly   false
        Javascript functionlens_Person_addresses(){returnlens('addresses');};
        Templated: false
        Deprecated false
    Field: telephone
        ViewType(typeName=one.xingyi.reference3.telephone.ITelephoneNumberViewDefn, forEntity=one.xingyi.reference3.telephone.server.domain.ITelephoneNumber, forView=one.xingyi.reference3.telephone.client.view.TelephoneNumberView, viewCompanion=one.xingyi.reference3.telephone.client.viewcompanion.TelephoneNumberViewCompanion, serverCompanion=one.xingyi.reference3.telephone.server.companion.TelephoneNumberCompanion, entityNameForLens=TelephoneNumber)
        Lens path  telephone/TelephoneNumber
        Lens name  lens_Person_telephone
        Readonly   false
        Javascript functionlens_Person_telephone(){returnlens('telephone');};
        Templated: false
        Deprecated false
    Field: address
        ViewType(typeName=one.xingyi.reference3.address.IAddressLine12ViewDefn, forEntity=one.xingyi.reference3.address.server.domain.IAddress, forView=one.xingyi.reference3.address.client.view.AddressLine12View, viewCompanion=one.xingyi.reference3.address.client.viewcompanion.AddressLine12ViewCompanion, serverCompanion=one.xingyi.reference3.address.server.companion.AddressCompanion, entityNameForLens=Address)
        Lens path  addresses/*address,{firstItem}
        Lens name  lens_Person_address
        Readonly   false
        Javascript functionlens_Person_address(){returncompose(lens_Person_addresses(),lensForFirstItemInList());};
        Templated: false
        Deprecated true
    Field: line1
        StringPrimitiveType()
        Lens path  addresses/*address,{firstItem},line1/string
        Lens name  lens_Person_line1
        Readonly   false
        Javascript functionlens_Person_line1(){returncompose(lens_Person_address(),lens('line1'));};
        Templated: false
        Deprecated true
    Field: line2
        StringPrimitiveType()
        Lens path  addresses/*address,{firstItem},line2/string
        Lens name  lens_Person_line2
        Readonly   false
        Javascript functionlens_Person_line2(){returncompose(lens_Person_address(),lens('line2'));};
        Templated: false
        Deprecated true
Get            Optional[GetDom()]
optionalGet    Optional[OptionalGetDom()]
Put            Optional[PutDom()]
Create         Optional[CreateDom()]
CreateNoId     Optional[CreateWithoutIdDom(path={host}/person)]
Delete         Optional[DeleteDom()]
prototype:     Optional[PrototypeDom(prototypeId=prototype)]
prototypeNoId: Optional.empty
Posts:         []
*/}
